package dk.nsp.idsas.security;

import dk.nsp.idsas.security.model.IdsasActor;
import dk.nsp.idsas.util.WhitelistType;

public class IdsasActorBuilder {
    private final IdsasActorProvider idsasActorProvider;
    private final IdsasActorTransformer idsasActorTransformer;
    private final IdsasActorEnricher idsasActorEnricher;
    private final IdsasActorValidator idsasActorValidator;

    public IdsasActorBuilder(IdsasActorProvider idsasActorProvider,
                             IdsasActorTransformer idsasActorTransformer,
                             IdsasActorEnricher idsasActorEnricher,
                             IdsasActorValidator idsasActorValidator) {
        this.idsasActorProvider = idsasActorProvider;
        this.idsasActorTransformer = idsasActorTransformer;
        this.idsasActorEnricher = idsasActorEnricher;
        this.idsasActorValidator = idsasActorValidator;
    }

    public IdsasActor getValidatedActor(WhitelistType whitelistType) throws IdsasSecurityException {

        IdsasActor idsasActor = idsasActorProvider.getActor();
        idsasActor = idsasActorTransformer.transformActor(idsasActor);
        idsasActor = idsasActorEnricher.enrichActor(idsasActor);
        return idsasActorValidator.validateIdsasActor(idsasActor, whitelistType);
    }

    public IdsasActor getValidatedActor() throws IdsasSecurityException {

        IdsasActor idsasActor = idsasActorProvider.getActor();
        idsasActor = idsasActorTransformer.transformActor(idsasActor);
        return idsasActorEnricher.enrichActor(idsasActor);
    }
}
