package dk.nsp.idsas.util;

import dk.sds.nsp.audit.AuditBuilder;
import dk.sds.nsp.audit.AuditBuilder.TypeOfInformation;

import javax.xml.datatype.XMLGregorianCalendar;

public class AuditLogger {
    private static final String COMPONENT = "IDSAS";
    private static final String CREATE_BLURRING_CONTEXT = "createBlurring";
    private static final String GET_SALT_CONTEXT = "getSalt";
    private static final String GET_CURRENT_SALT_CONTEXT = "getCurrentSalt";
    private static final String GET_BLURRED_ORGANISATIONS_CONTEXT = "getBlurredOrganisations";

    public void logCreateBlurring(AuditBuilder auditBuilder, String cpr, String cvr) {
        auditLog(auditBuilder, CREATE_BLURRING_CONTEXT, Type.CPR, cpr);
        auditLog(auditBuilder, CREATE_BLURRING_CONTEXT, Type.CVR, cvr);
    }

    public void logGetSalt(AuditBuilder auditBuilder, String cvr, XMLGregorianCalendar dateTime) {
        auditLog(auditBuilder, GET_SALT_CONTEXT, Type.CVR, cvr);
        auditLog(auditBuilder, GET_SALT_CONTEXT, Type.DATE_TIME, dateTime);
    }

    public void logGetCurrentSalt(AuditBuilder auditBuilder, String cvr) {
        auditLog(auditBuilder, GET_CURRENT_SALT_CONTEXT, Type.CVR, cvr);
    }

    public void logGetBlurredOrganisations(AuditBuilder auditBuilder, String cpr) {
        auditLog(auditBuilder, GET_BLURRED_ORGANISATIONS_CONTEXT, Type.CPR, cpr);
    }

    private void auditLog(AuditBuilder auditBuilder, String context, Type type, Object value) {
        auditBuilder.addAuditInformation(COMPONENT, context, type.typeOfInformation, type.value, value);
    }

    private enum Type {
        CPR("cpr", TypeOfInformation.RegularPersonalInformation),
        CVR("cvr", TypeOfInformation.NonPersonalInformation),
        DATE_TIME("dateTime", TypeOfInformation.NonPersonalInformation);

        private final String value;
        private final TypeOfInformation typeOfInformation;

        Type(String value, AuditBuilder.TypeOfInformation typeOfInformation) {
            this.value = value;
            this.typeOfInformation = typeOfInformation;
        }
    }
}
