package dk.nsp.idsas.setup;

import dk.nsp.idsas.dao.AlivenessDao;
import dk.nsp.idsas.dao.WhitelistDao;
import dk.nsp.idsas.http.PoolingHttpClientFactory;
import dk.nsp.idsas.personinformation.PersonInformationClient;
import dk.nsp.idsas.security.*;
import dk.nsp.idsas.security.impl.IdsasActorProviderImpl;
import dk.nsp.idsas.security.impl.IdsasActorValidatorImpl;
import dk.nsp.idsas.service.BlurringService;
import dk.nsp.idsas.util.AuditLogger;

import org.apache.http.client.HttpClient;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.PropertySource;
import org.springframework.context.annotation.PropertySources;
import org.springframework.jdbc.datasource.lookup.JndiDataSourceLookup;

import javax.sql.DataSource;
import java.time.Duration;

@Configuration
@PropertySources({
        @PropertySource(value = "idsas.properties", encoding = "ISO-8859-1")
})
public class ServiceSetup {
    public static final String ANNOTATION_CONFIG_CONTEXT = "ANNOTATION_CONFIG_APPLICATION_CONTEXT";
    private static final Logger logger = Logger.getLogger(ServiceSetup.class);

    @Value("${idsas.datasource.jndi}")
    private String dataSourceName;

    @Value("${personinformation.url}")
    private String personInformationUrl;

    @Value("${personinformation.errorcount.duration:PT10M}")
    private String personInformationErrorCountDuration;

    @Value("${idsas.allowed.client.system.name:http://system.nspop.dk/sts}")
    private String clientSystemName;

    @Bean
    public DataSource dataSource() {
        return new JndiDataSourceLookup().getDataSource(dataSourceName);
    }

    @Bean
    public AlivenessDao alivenessDao(DataSource dataSource) {
        return new AlivenessDao(dataSource);
    }

    @Bean WhitelistDao whitelistDao(DataSource dataSource) {
        return new WhitelistDao(dataSource);
    }

    @Bean
    public IdsasActorBuilder idsasActorBuilder(WhitelistDao whitelistDao) {
        IdsasActorProvider provider = new IdsasActorProviderImpl();
        IdsasActorTransformer transformer = actor -> actor; // No transforming
        IdsasActorEnricher enricher = actor -> actor; // No enriching
        IdsasActorValidator validator = new IdsasActorValidatorImpl(whitelistDao);
        return new IdsasActorBuilder(provider, transformer, enricher, validator);
    }

    @Bean
    public PersonInformationClient personInformationClient() {
        HttpClient httpClient = new PoolingHttpClientFactory().getClient();
        return new PersonInformationClient(httpClient, personInformationUrl, Duration.parse(personInformationErrorCountDuration));
    }

    @Bean
    public BlurringService blurringService() {
        return new BlurringService();
    }

    @Bean
    public AuditLogger auditLogger() {
        return new AuditLogger();
    }

}
