package dk.nsp.idsas.setup;

import dk.nsp.idsas.dao.AlivenessDao;
import dk.nsp.idsas.personinformation.PersonInformationClient;
import dk.nsp.idsas.util.health.DBHealthIndicator;
import dk.nsp.idsas.util.health.HealthIndicator;
import dk.nsp.idsas.util.health.PersonInformationHealthIndicator;
import dk.nsp.idsas.util.health.VersionIndicator;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.PropertySource;
import org.springframework.context.annotation.PropertySources;

@Configuration
@PropertySources({
        @PropertySource("classpath:/META-INF/maven/dk.nsp.idsas/idsas-web/pom.properties"),
        @PropertySource(value = "idsas.properties", encoding = "ISO-8859-1")
        // Bemærkning: I Java 8 er properties altid i ISO-8859-1, men fremadrettet skulle de gerne kunne være UTF-8.
})
public class WebSetup {

    @Value("${version}")
    private String version;

    @Value("${personinformation.error.tolerance:0}")
    private int personInformationErrorTolerance;

    @Bean
    public HealthIndicator versionIndicator() {
        return new VersionIndicator(version);
    }

    @Bean
    public DBHealthIndicator dbHealthIndicator(AlivenessDao alivenessDao) {
        return new DBHealthIndicator(alivenessDao);
    }

    @Bean
    public PersonInformationHealthIndicator personInformationHealthIndicator(PersonInformationClient personInformationClient) {
        return new PersonInformationHealthIndicator(personInformationClient, personInformationErrorTolerance);
    }
}
