package dk.nsp.idsas.personinformation;

import org.junit.Test;

import java.time.Duration;

import static org.junit.Assert.assertEquals;

public class ServiceErrorCallbackTest {

    @Test
    public void getErrorCount_WhenNothingHasBeenRegistered_Returns0() {
        ServiceErrorCallback serviceErrorCallback = new ServiceErrorCallback(Duration.ofMinutes(10));

        int errorCount = serviceErrorCallback.getErrorCount();

        assertEquals(0, errorCount);
    }

    @Test
    public void getErrorCount_WhenSuccessHasBeenRegistered_Returns0() {
        ServiceErrorCallback serviceErrorCallback = new ServiceErrorCallback(Duration.ofMinutes(10));
        serviceErrorCallback.registerServiceSuccess();

        int errorCount = serviceErrorCallback.getErrorCount();

        assertEquals(0, errorCount);
    }

    @Test
    public void getErrorCount_WhenTwoErrorsHasBeenRegisteredWithinTimeLimit_Returns2() {
        ServiceErrorCallback serviceErrorCallback = new ServiceErrorCallback(Duration.ofMinutes(10));
        serviceErrorCallback.registerServiceError();
        serviceErrorCallback.registerServiceError();

        int errorCount = serviceErrorCallback.getErrorCount();

        assertEquals(2, errorCount);
    }

    @Test
    public void getErrorCount_WhenTwoErrorsHasBeenRegisteredBeforeTimeLimit_Returns0() {
        ServiceErrorCallback serviceErrorCallback = new ServiceErrorCallback(Duration.ofMinutes(-1));
        serviceErrorCallback.registerServiceError();
        serviceErrorCallback.registerServiceError();

        int errorCount = serviceErrorCallback.getErrorCount();

        assertEquals(0, errorCount);
    }

    @Test
    public void getErrorCount_WhenTwoErrorsHasBeenRegisteredWithinTimeLimitButSuccessAfterwards_Returns0() {
        ServiceErrorCallback serviceErrorCallback = new ServiceErrorCallback(Duration.ofMinutes(10));
        serviceErrorCallback.registerServiceError();
        serviceErrorCallback.registerServiceError();
        serviceErrorCallback.registerServiceSuccess();

        int errorCount = serviceErrorCallback.getErrorCount();

        assertEquals(0, errorCount);
    }
}